@@ -1,9 +1,19 @@
 #' Join a data-loanbook object to the abcd and scenario
 #'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function was deprecated because it is not required as a user-facing
+#' function for PACTA for Banks. It is still used internally though.
+#' All relevant outputs of the PACTA for Banks analysis can be obtained using
+#' the target_market_share() and target_sda() functions.
+#'
 #' `join_abcd_scenario()` is a simple wrapper of several calls to
 #' `dplyr::join_*()`, forming the master dataset to be used in later steps of
 #' the analysis.
 #'
+#' @keywords internal
+#'
 #' @param data A data frame like the output of
 #'   `r2dii.match::prioritize`.
 #' @param abcd An asset level data frame like [r2dii.data::abcd_demo].
@@ -39,6 +49,7 @@ join_abcd_scenario <- function(data,
                               scenario,
                               region_isos = r2dii.data::region_isos,
                               add_green_technologies = FALSE) {
+  lifecycle::deprecate_soft(when = "0.5.0", what = "join_abcd_scenario()")
 
   check_portfolio_abcd_scenario(data, abcd, scenario)
 
@@ -160,9 +171,10 @@ add_green_technologies_to_abcd <- function(data, scenario) {
     unique() %>%
     inner_join(increasing_techs, by = c("sector", "technology"))
 
-  increasing_techs_not_in_abcd <- dplyr::filter(
+  increasing_techs_not_in_abcd <- dplyr::anti_join(
     increasing_techs_in_scenario,
-    !(.data[["technology"]] %in% unique(data$technology))
+    data,
+    by = c("sector", "technology")
   )
 
   green_rows_to_add <- data %>%
